@@ -1,14 +1,14 @@
 package Evo::Class::Attrs::XS;
 use Evo 'XSLoader; -Export';
 
-use constant {ECA_SIMPLE => 0, ECA_DEFAULT => 1, ECA_DEFAULT_CODE => 2, ECA_REQUIRED => 3,
+use constant {ECA_OPTIONAL => 0, ECA_DEFAULT => 1, ECA_DEFAULT_CODE => 2, ECA_REQUIRED => 3,
   ECA_LAZY => 4,};
 
 export qw(
-  ECA_SIMPLE ECA_DEFAULT ECA_DEFAULT_CODE ECA_REQUIRED ECA_LAZY
+  ECA_OPTIONAL ECA_DEFAULT ECA_DEFAULT_CODE ECA_REQUIRED ECA_LAZY
 );
 
-our $VERSION = '0.0248';    # VERSION
+our $VERSION = '0.0249';    # VERSION
 
 # to be able to run with and without dzil
 my $version = eval '$VERSION';    ## no critic
@@ -34,7 +34,7 @@ Evo::Class::Attrs::XS - XS implementation of attributes and "new" method generat
 
 =head1 VERSION
 
-version 0.0248
+version 0.0249
 
 =head1 AUTHOR
 
