@@ -1,14 +1,12 @@
 package Evo::Class::Meta;
-use Evo 'Carp croak; Scalar::Util reftype; -Lib strict_opts; -Internal::Util; Module::Load ()';
-use Evo '/::Attrs *';
-
+use Evo 'Carp croak; Scalar::Util reftype; -Internal::Util; Module::Load ()';
+use Evo '/::Attrs *; /::Syntax *';
 
 our @CARP_NOT = qw(Evo::Class);
 
 sub register ($me, $package) {
-  my $self = Evo::Internal::Util::pkg_stash($package, $me);
-  return $self if $self;
-  $self = bless {
+  no strict 'refs';    ## no critic
+  ${"${package}::EVO_CLASS_META"} ||= bless {
     package    => $package,
     private    => {},
     attrs      => Evo::Class::Attrs->new,
@@ -16,12 +14,11 @@ sub register ($me, $package) {
     reqs       => {},
     overridden => {}
   }, $me;
-  Evo::Internal::Util::pkg_stash($package, $me, $self);
-  $self;
 }
 
 sub find_or_croak ($self, $package) {
-  Evo::Internal::Util::pkg_stash($package, $self) or croak "$package isn't Evo::Class";
+  no strict 'refs';    ## no critic
+  ${"${package}::EVO_CLASS_META"} or croak "$package isn't Evo::Class";
 }
 
 sub package($self) { $self->{package} }
@@ -79,7 +76,7 @@ sub _check_exists_valid_name ($self, $name) {
   _check_exists($self, $name);
 }
 
-sub reg_attr ($self, $name, @opts) {
+sub _reg_parsed_attr ($self, $name, @opts) {
   _check_exists_valid_name($self, $name);
   my $pkg = $self->package;
   croak qq{$pkg already has subroutine "$name"} if Evo::Internal::Util::names2code($pkg, $name);
@@ -91,7 +88,7 @@ sub reg_attr ($self, $name, @opts) {
   Evo::Internal::Util::monkey_patch $pkg, $name, $sub;
 }
 
-sub reg_attr_over ($self, $name, @opts) {
+sub _reg_parsed_attr_over ($self, $name, @opts) {
   _check_valid_name($self, $name);
   $self->mark_as_overridden($name);
   my $sub = $self->attrs->gen_attr($name, @opts);    # register
@@ -99,6 +96,16 @@ sub reg_attr_over ($self, $name, @opts) {
   Evo::Internal::Util::monkey_patch_silent $pkg, $name, $sub;
 }
 
+sub reg_attr ($self, $name, @attr) {
+  my @opts = $self->parse_attr(@attr);
+  $self->_reg_parsed_attr($name, @opts);
+}
+
+sub reg_attr_over ($self, $name, @attr) {
+  my @opts = $self->parse_attr(@attr);
+  $self->_reg_parsed_attr_over($name, @opts);
+}
+
 # means register external sub as method. Because every sub in the current package
 # is public by default
 sub reg_method ($self, $name) {
@@ -143,7 +150,7 @@ sub extend_with ($self, $source_p) {
 
   foreach my $slot ($source->_public_attrs_slots) {
     next if $self->is_overridden($slot->{name});
-    $self->reg_attr(@$slot{qw(name type value check ro inject)});
+    $self->_reg_parsed_attr(@$slot{qw(name type value check ro inject)});
     push @new_attrs, $slot->{name};
   }
 
@@ -192,46 +199,25 @@ sub check_implementation ($self, $inter_class) {
 # check?
 # is_ro?
 
-my @KNOWN_HAS = qw(default required lazy check is inject);
-
 sub parse_attr ($me, @attr) {
-  my %unknown = my %opts = (@attr % 2 ? (default => @attr) : @attr);
-  delete $unknown{$_} for @KNOWN_HAS;
-  croak "unknown options: " . join(',', sort keys %unknown) if keys %unknown;
+  my @scalars = grep { $_ ne SYNTAX_STATE } @attr;
+  croak "expected 1 scalar, got: " . join ',', @scalars if @scalars > 1;
+  my %state = syntax_reset;
 
-  #use constant {I_NAME => 0, I_TYPE => 1, I_RO => 2, I_CHECK => 3, I_VALUE => 4};
-  my ($type, $ro, $check, $value);
+  croak qq#"optional" flag makes no sense with default("$scalars[0]")#
+    if $state{optional} && @scalars;
+  croak qq#"lazy" requires code reference#
+    if $state{lazy} && (reftype($scalars[0]) // '') ne 'CODE';
+  croak qq#default("$scalars[0]") should be either a scalar or a code reference#
+    if @scalars && ref($scalars[0]) && reftype($scalars[0]) ne 'CODE';
 
-  # detect rtype
-  my $seen = 0;
-  if (exists $opts{default}) {
-    croak qq#"default" should be either a code reference or a scalar value#
-      if ref($opts{default}) && (reftype($opts{default}) // '') ne 'CODE';
-    ++$seen;
-    $type = ref($opts{default}) ? ECA_DEFAULT_CODE : ECA_DEFAULT;
-    $value = $opts{default};
-  }
-  do { ++$seen; $type = ECA_REQUIRED; } if $opts{required};
-  if (exists $opts{lazy}) {
-    croak qq#"lazy" should be a code reference# if (reftype($opts{lazy}) // '') ne 'CODE';
-    ++$seen;
-    $type  = ECA_LAZY;
-    $value = $opts{lazy};
-  }
-  croak qq{providing more than one of "default", "lazy", "required" doesn't make sense}
-    if $seen > 1;
 
-  croak qq#"check" should be a code reference#
-    if exists($opts{check}) && (reftype($opts{check}) // '') ne 'CODE';
-
-  my $is = $opts{is} // 'rw';
-  croak qq#invalid "is": "$is"# unless $is eq 'ro' || $is eq 'rw';
-
-  $ro = $is eq 'ro' ? 1 : 0;
-  $check = $opts{check} if exists $opts{check};
-  $type ||= ECA_SIMPLE;
-
-  return ($type, $value, $check, $ro, $opts{inject});
+  my $type;
+  if    ($state{optional}) { $type = ECA_OPTIONAL if $state{optional}; }
+  elsif ($state{lazy})     { $type = ECA_LAZY     if $state{lazy}; }
+  elsif (@scalars) { $type = ref($scalars[0]) ? ECA_DEFAULT_CODE : ECA_DEFAULT; }
+  else             { $type = ECA_REQUIRED; }
+  return ($type, $scalars[0], $state{check}, $state{rw} ? 0 : 1, $state{inject});
 }
 
 sub info($self) {
@@ -262,7 +248,26 @@ Evo::Class::Meta
 
 =head1 VERSION
 
-version 0.0248
+version 0.0249
+
+=head1 SYNOPSYS
+
+  use Evo;
+  {
+
+    package Foo::Bar;
+    use Evo::Class;
+  }
+
+  say Foo::Bar->META;
+  say Foo::Bar->META->attrs;
+  say $Foo::Bar::EVO_CLASS_META;
+  say $Foo::Bar::EVO_CLASS_META->attrs;
+  say $Foo::Bar::EVO_CLASS_META->{attrs};
+
+  Foo::Bar->META->reg_attr('foo');
+  use Data::Dumper;
+  say Dumper (Foo::Bar->META->attrs->slots);
 
 =head1 METHODS
 
@@ -271,7 +276,11 @@ version 0.0248
 Register a meta instance only once. The second invocation will return the same instance.
 But if it will be called from another subclass, die. This is a protection from the fool
 
-Meta is stored in C<$Some::Class::META_CLASS> global variable and lives as long as a package.
+Meta is stored in C<$Some::Class::EVO_CLASS_META> global variable and lives as long as a package.
+
+=head2 attrs
+
+Returns an inctance of attributes generator L<Evo::Class::Attrs>
 
 =head1 IMPLEMENTATION NOTES
 
@@ -280,7 +289,7 @@ Meta is stored in C<$Some::Class::META_CLASS> global variable and lives as long
 "overridden" means this symbol will be skept during L</extend_with> so if you marked something as overridden, you should define method or sub yourself too.  This is not a problem with C<sub foo : Over {}> or L</reg_attr_over> because it marks symbol as overridden and also registers a symbol.
 
 BUT!!!
-Calling L</reg_attr_over> should be called
+L</reg_attr_over> should be called
 
 =head2 private
 
