@@ -79,7 +79,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0248
+version 0.0249
 
 =head1 DESCRIPTION
 
@@ -141,7 +141,7 @@ Firstly you need to load L<Evo::Export> with C<import> (or C<*>). This will impo
 By default, C<use Your::Module;>, without arguments will import nothing. You can change this behaviour to export all without arguments
 
   use Evo '-Export import_all:import';
-  use Evo '-Export *, -import, import_all:import';
+  use Evo '-Export * -import import_all:import';
 
 Using attribute C<Export>
 
@@ -248,9 +248,28 @@ Better using with C<ExportGen> attribute
 
 =head4 EXPORT
 
-This method returns a bound instance of L<Evo::Export::Meta>.
+This method returns a bound instance of L<Evo::Export::Meta>, which is stored in package's C<$EVO_EXPORT_META> variable.
+Also a cache for generated export is stored in class'es C<$EVO_EXPORT_CACHE> variable
 
-  say Dumper __PACKAGE__->EXPORT->info;
+  use Evo;
+  {
+
+    package My::Lib;
+    use Evo '-Export *', -Loaded;
+    sub foo : Export { }
+
+    sub bar : ExportGen {
+      sub { }
+    }
+
+    package My::Dest;
+    use My::Lib '*';
+  }
+
+  use Data::Dumper;
+  say Dumper (My::Lib->EXPORT->info);
+  say Dumper ($My::Lib::EVO_EXPORT_META->info);
+  say "cache of My::Dest: ", Dumper($My::Dest::EVO_EXPORT_CACHE);
 
 =head4 import
 
