@@ -6,25 +6,19 @@ our @CARP_NOT = qw(Evo Evo::Export Evo::Internal::Util);
 sub package($self) { $self->{package} }
 sub symbols($self) { $self->{symbols} //= {} }
 
-# build once per package or die
-sub bind_to ($me, $pkg, %opts) {
-  croak "$pkg already has $me instance" if Evo::Internal::Util::pkg_stash($pkg, $me);
-  my $obj = $me->new($pkg, %opts);
-  Evo::Internal::Util::pkg_stash($pkg, $me, $obj);
-}
-
 sub new ($me, $pkg, %opts) {
   $me = ref($me) if ref $me;
   bless {%opts, package => $pkg}, $me;
 }
 
-sub find_or_bind_to ($class, $package, %opts) {
-  my $obj = Evo::Internal::Util::pkg_stash($package, $class);
-  $obj = $class->bind_to($package, %opts) if !$obj;
-  $obj;
+sub find_or_bind_to ($me, $pkg, %opts) {
+  no strict 'refs';    ## no critic
+  no warnings 'once';
+  ${"${pkg}::EVO_EXPORT_META"} ||= $me->new($pkg, %opts);
 }
 
 # it's important to return same function for the same module
+# we're storing it in the module, not in slot, to be able to easy destroy a module
 sub request ($self, $name, $dpkg) {
   my $slot = $self->find_slot($name);
   my $fn;
@@ -33,8 +27,12 @@ sub request ($self, $name, $dpkg) {
     $fn = $slot->{code};
   }
   elsif ($type eq 'gen') {
-    return $slot->{cache}{$dpkg} if $slot->{cache}{$dpkg};
-    return $slot->{cache}{$dpkg} = $slot->{gen}->($self->package, $dpkg);
+    no warnings 'once';
+    no strict 'refs';    ## no critic
+    my $pkg = $self->package;
+    my $cache = ${"${dpkg}::EVO_EXPORT_CACHE"} ||= {};
+    return $cache->{$pkg}{$name} if $cache->{$pkg}{$name};
+    return $cache->{$pkg}{$name} = $slot->{gen}->($self->package, $dpkg);
   }
 
   croak "Something wrong" unless $fn;
@@ -140,7 +138,7 @@ Evo::Export::Meta
 
 =head1 VERSION
 
-version 0.0248
+version 0.0249
 
 =head1 AUTHOR
 
