@@ -1,8 +1,8 @@
 package Evo::Promise::Sync;
 use Evo '-Class *';
 
-has 'promise', required => 1, is => 'ro';
-has $_ for qw(called v blocking should_resolve);
+has 'promise';
+has $_, optional, rw for qw(called v blocking should_resolve);
 
 sub reject ($self, $r) {
   return if $self->called;
@@ -41,7 +41,7 @@ Evo::Promise::Sync
 
 =head1 VERSION
 
-version 0.0248
+version 0.0249
 
 =head2 SYNOPSIS
 This class exists for internal purposes only to make C<d_resolve> a little bit
